==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/CUSTOMERCONTRACTCLAUSEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CUSTOMERCONTRACTCLAUSEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CUSTOMERCONTRACTCLAUSEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERCONTRACTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLAUSEID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUSTOMERCONTRACTCLAUSEID_Type", propOrder = {
    "usercontractid",
    "clauseid"
})
public class CUSTOMERCONTRACTCLAUSEID_Type {

    @XmlElement(name = "USERCONTRACTID", required = true)
    protected USERCONTRACTID_Type usercontractid;
    @XmlElement(name = "CLAUSEID", required = true)
    protected CLAUSEID_Type clauseid;

    /**
     * Obtient la valeur de la propriété usercontractid.
     * 
     * @return
     *     possible object is
     *     {@link USERCONTRACTID_Type }
     *     
     */
    public USERCONTRACTID_Type getUSERCONTRACTID() {
        return usercontractid;
    }

    /**
     * Définit la valeur de la propriété usercontractid.
     * 
     * @param value
     *     allowed object is
     *     {@link USERCONTRACTID_Type }
     *     
     */
    public void setUSERCONTRACTID(USERCONTRACTID_Type value) {
        this.usercontractid = value;
    }

    /**
     * Obtient la valeur de la propriété clauseid.
     * 
     * @return
     *     possible object is
     *     {@link CLAUSEID_Type }
     *     
     */
    public CLAUSEID_Type getCLAUSEID() {
        return clauseid;
    }

    /**
     * Définit la valeur de la propriété clauseid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLAUSEID_Type }
     *     
     */
    public void setCLAUSEID(CLAUSEID_Type value) {
        this.clauseid = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/CUSTOMERCONTRACTCLAUSEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CUSTOMERCONTRACTCLAUSEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CUSTOMERCONTRACTCLAUSEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERCONTRACTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLAUSEID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUSTOMERCONTRACTCLAUSEID_Type", propOrder = {
    "usercontractid",
    "clauseid"
})
public class CUSTOMERCONTRACTCLAUSEID_Type {

    @XmlElement(name = "USERCONTRACTID", required = true)
    protected USERCONTRACTID_Type usercontractid;
    @XmlElement(name = "CLAUSEID", required = true)
    protected CLAUSEID_Type clauseid;

    /**
     * Gets the value of the usercontractid property.
     * 
     * @return
     *     possible object is
     *     {@link USERCONTRACTID_Type }
     *     
     */
    public USERCONTRACTID_Type getUSERCONTRACTID() {
        return usercontractid;
    }

    /**
     * Sets the value of the usercontractid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERCONTRACTID_Type }
     *     
     */
    public void setUSERCONTRACTID(USERCONTRACTID_Type value) {
        this.usercontractid = value;
    }

    /**
     * Gets the value of the clauseid property.
     * 
     * @return
     *     possible object is
     *     {@link CLAUSEID_Type }
     *     
     */
    public CLAUSEID_Type getCLAUSEID() {
        return clauseid;
    }

    /**
     * Sets the value of the clauseid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLAUSEID_Type }
     *     
     */
    public void setCLAUSEID(CLAUSEID_Type value) {
        this.clauseid = value;
    }

}
